@@ -84,6 +84,8 @@ class Quip:
                              help='Update only new_uuid with a valid UUID in the template')
         parser_update.add_argument('--template', '-t', action='store_true',
                              help='create template instead of extension')
+        parser_update.add_argument('--rename_scripts', action='store_true',
+                             help='add .py extensions to script files.')
         
         parser_fields = subparsers.add_parser('fields', aliases=FIELD_ACTION[1:], help='Updates or dumps template.json fields.')
         parser_fields.add_argument('name', nargs="?", help='name of the project')
@@ -183,7 +185,10 @@ class Quip:
             elif self.args.dump:
                 self.dump_fields(write=True)
         elif action in UPDATE_ACTION:
-            self.update_project(self.args.uuid, self.args.new_uuid)
+            if self.args.rename_scripts:
+                self.update_rename_scripts()
+            else:
+                self.update_project(self.args.uuid, self.args.new_uuid)
         elif action in DELETE_ACTION:
             self.delete_project()
         elif action in CLONE_ACTION:
@@ -293,6 +298,12 @@ class Quip:
             self.update_uip_config(self.project_name)
         self.update_template_json(self.project_name, update_uuid, update_new_uuid)
 
+    def update_rename_scripts(self):
+        for _script in ["script", "scriptUnix", "scriptWindows"]:
+            script_path = self.join_path("src", "templates", _script)
+            if os.path.exists(script_path):
+                os.rename(script_path, script_path + ".py")
+
     def update_icon(self):
         from PIL import Image
         import PIL
@@ -843,7 +854,9 @@ class Quip:
 
             _json = json.loads(template_content)
             if _json["useCommonScript"]:
-                script_path = self.join_path("src", "templates", "script")
+                script_path = self.join_path("src", "templates", "script.py")
+                if not os.path.exists(script_path):
+                    script_path = self.join_path("src", "templates", "script")
                 script_content = self.read_file_content(script_path)
                 _json["script"] = r"""{}""".format(script_content)
                 _json["scriptUnix"] = None
@@ -851,12 +864,16 @@ class Quip:
             else:
                 _json["script"] = None
                 if _json["agentType"] in ["Linux/Unix", "Any"]:
-                    script_unix_path = self.join_path("src", "templates", "scriptUnix")
+                    script_unix_path = self.join_path("src", "templates", "scriptUnix.py")
+                    if not os.path.exists(script_unix_path):
+                        script_unix_path = self.join_path("src", "templates", "scriptUnix")
                     script_unix_content = self.read_file_content(script_unix_path)
                     _json["scriptUnix"] = script_unix_content #.replace('\n', '\\n')
 
                 if _json["agentType"] in ["Windows", "Any"]:
-                    script_windows_path = self.join_path("src", "templates", "scriptWindows")
+                    script_windows_path = self.join_path("src", "templates", "scriptWindows.py")
+                    if not os.path.exists(script_windows_path):
+                        script_windows_path = self.join_path("src", "templates", "scriptWindows")
                     script_windows_content = self.read_file_content(script_windows_path)
                     _json["scriptWindows"] = script_windows_content #.replace('\n', '\\n')
             
@@ -881,14 +898,14 @@ class Quip:
 
     def split_template_scripts(self, payload_json):
         if payload_json["useCommonScript"]:
-            script_path = self.join_path("src", "templates", "script")
+            script_path = self.join_path("src", "templates", "script.py")
             self.write_to_file(script_path, payload_json["script"])
         else:
             if payload_json["agentType"] in ["Linux/Unix", "Any"]:
-                script_unix_path = self.join_path("src", "templates", "scriptUnix")
+                script_unix_path = self.join_path("src", "templates", "scriptUnix.py")
                 self.write_to_file(script_unix_path, payload_json["scriptUnix"])
             if payload_json["agentType"] in ["Windows", "Any"]:
-                script_windows_path = self.join_path("src", "templates", "scriptWindows")
+                script_windows_path = self.join_path("src", "templates", "scriptWindows.py")
                 self.write_to_file(script_windows_path, payload_json["scriptWindows"])
 
         payload_json["script"] = None
